==> blaccount_flutter_plugin-0.1.5.tar.gz: lib/blaccount_flutter_plugin.dart <==

import 'dart:async';

import 'package:flutter/services.dart';

class BlaccountFlutterPlugin {
  static const MethodChannel _channel =
      const MethodChannel('blaccount_flutter_plugin');

  static Future<String?> get platformVersion async {
    final String? version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  //初始化SDK
  static Future<bool?> init() async {
    final bool? result =  await _channel.invokeMethod('init_blsdk_account');
    return result;
  }
  //帐号密码登录
  static Future<String?> login(String account,String password) async {
    final String? result =  await _channel.invokeMethod('login'
        ,<String,dynamic>{'account':account,'password':password});
    return result;
  }

  //帐号密码登录
  static Future<String?> localLogin(String loginSession,String userId) async {
    final String? result =  await _channel.invokeMethod('local_login'
        ,<String,dynamic>{'login_session':loginSession,'user_id':userId});
    return result;
  }

  //快速登录验证码
  static Future<String?> sendFasetLoginVCode(String account,String countryCode) async {
    final String? result =  await _channel.invokeMethod('send_fast_login_vcode'
        ,<String,dynamic>{'account':account,'country_code':countryCode});
    return result;
  }

  //快速登录
  static Future<String?> fastLogin(String account,String countryCode,String vcode) async {
    final String? result =  await _channel.invokeMethod('fast_login'
        ,<String,dynamic>{'account':account,'country_code':countryCode,'vcode':vcode});
    return result;
  }

  //手机注册帐号验证码
  static Future<String?> sendPhoneRegVCode(String phone,String countryCode) async {
    final String? result =  await _channel.invokeMethod('send_phone_reg_vcode'
        ,<String,dynamic>{'phone':phone,'country_code':countryCode});
    return result;
  }

  //邮箱注册帐号验证码
  static Future<String?> sendEmailRegVCode(String email) async {
    final String? result =  await _channel.invokeMethod('send_email_reg_vcode'
        ,<String,dynamic>{'email':email});
    return result;
  }

  //注册帐号
  static Future<String?> regist(String data) async {
    final String? result =  await _channel.invokeMethod('regist'
        ,<String,dynamic>{'data':data});
    return result;
  }


  //重置密码验证码
  static Future<String?> sendResetPwdVCode(String account) async {
    final String? result =  await _channel.invokeMethod('send_reset_pwd_vcode'
        ,<String,dynamic>{'account':account});
    return result;
  }

  //重置密码验
  static Future<String?> resetPwd(String account,String vcode,String password) async {
    final String? result =  await _channel.invokeMethod('reset_password'
        ,<String,dynamic>{'account':account,'vcode':vcode,'password':password});
    return result;
  }

  //修手机验证码
  static Future<String?> sendModifyPhoneVCode(String phone,String countryCode) async {
    final String? result =  await _channel.invokeMethod('send_modify_phone_vcode'
        ,<String,dynamic>{'phone':phone,'country_code':countryCode});
    return result;
  }


  //修改邮箱验证码
  static Future<String?> sendModifyEmialVCode(String email) async {
    final String? result =  await _channel.invokeMethod('send_modify_email_vcode'
        ,<String,dynamic>{'email':email});
    return result;
  }

  //修手机
  static Future<String?> modifyPhone(String phone,String countryCode,String vcode,String password) async {
    final String? result =  await _channel.invokeMethod('modify_phone'
        ,<String,dynamic>{'phone':phone,'country_code':countryCode,'vcode':vcode,'password':password});
    return result;
  }


  //修改邮箱
  static Future<String?> modifyEmial(String email,String vcode,String password) async {
    final String? result =  await _channel.invokeMethod('modify_email'
        ,<String,dynamic>{'email':email,'vcode':vcode,'password':password});
    return result;
  }

  //修改密码
  static Future<String?> modifyPassword(String oldPassword,String newPassword) async {
    final String? result =  await _channel.invokeMethod('modify_password'
        ,<String,dynamic>{'old_password':oldPassword,'new_password':newPassword});
    return result;
  }

  //修改昵称
  static Future<String?> modifyNickname(String nickname,String newPassword) async {
    final String? result =  await _channel.invokeMethod('modify_nickname'
        ,<String,dynamic>{'nickname':nickname});
    return result;
  }

  //修改头像
  static Future<String?> modifyIcon(String filePath) async {
    final String? result =  await _channel.invokeMethod('modify_icon'
        ,<String,dynamic>{'file_path':filePath});
    return result;
  }

  //获取用户信息
  static Future<String?> queryUsersInfo(String data) async {
    final String? result =  await _channel.invokeMethod('query_users_info'
        ,<String,dynamic>{'data':data});
    return result;
  }
}

==> blaccount_flutter_plugin-0.1.6.tar.gz: lib/blaccount_flutter_plugin.dart <==

import 'dart:async';

import 'package:flutter/services.dart';

class BlaccountFlutterPlugin {
  static const MethodChannel _channel =
      const MethodChannel('blaccount_flutter_plugin');

  static Future<String?> get platformVersion async {
    final String? version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  //初始化SDK
  static Future<bool?> init() async {
    final bool? result =  await _channel.invokeMethod('init_blsdk_account');
    return result;
  }
  //帐号密码登录
  static Future<String?> login(String account,String password) async {
    final String? result =  await _channel.invokeMethod('login'
        ,<String,dynamic>{'account':account,'password':password});
    return result;
  }

  //帐号密码登录
  static Future<String?> localLogin(String loginSession,String userId) async {
    final String? result =  await _channel.invokeMethod('local_login'
        ,<String,dynamic>{'login_session':loginSession,'user_id':userId});
    return result;
  }

  //快速登录验证码
  static Future<String?> sendFasetLoginVCode(String account,String countryCode) async {
    final String? result =  await _channel.invokeMethod('send_fast_login_vcode'
        ,<String,dynamic>{'account':account,'country_code':countryCode});
    return result;
  }

  //快速登录
  static Future<String?> fastLogin(String account,String countryCode,String vcode) async {
    final String? result =  await _channel.invokeMethod('fast_login'
        ,<String,dynamic>{'account':account,'country_code':countryCode,'vcode':vcode});
    return result;
  }

  //手机注册帐号验证码
  static Future<String?> sendPhoneRegVCode(String phone,String countryCode) async {
    final String? result =  await _channel.invokeMethod('send_phone_reg_vcode'
        ,<String,dynamic>{'phone':phone,'country_code':countryCode});
    return result;
  }

  //邮箱注册帐号验证码
  static Future<String?> sendEmailRegVCode(String email) async {
    final String? result =  await _channel.invokeMethod('send_email_reg_vcode'
        ,<String,dynamic>{'email':email});
    return result;
  }

  //注册帐号
  static Future<String?> regist(String data) async {
    final String? result =  await _channel.invokeMethod('regist'
        ,<String,dynamic>{'data':data});
    return result;
  }


  //重置密码验证码
  static Future<String?> sendResetPwdVCode(String account) async {
    final String? result =  await _channel.invokeMethod('send_reset_pwd_vcode'
        ,<String,dynamic>{'account':account});
    return result;
  }

  //重置密码验
  static Future<String?> resetPwd(String account,String vcode,String password) async {
    final String? result =  await _channel.invokeMethod('reset_password'
        ,<String,dynamic>{'account':account,'vcode':vcode,'password':password});
    return result;
  }

  //修手机验证码
  static Future<String?> sendModifyPhoneVCode(String phone,String countryCode) async {
    final String? result =  await _channel.invokeMethod('send_modify_phone_vcode'
        ,<String,dynamic>{'phone':phone,'country_code':countryCode});
    return result;
  }


  //修改邮箱验证码
  static Future<String?> sendModifyEmialVCode(String email) async {
    final String? result =  await _channel.invokeMethod('send_modify_email_vcode'
        ,<String,dynamic>{'email':email});
    return result;
  }

  //修手机
  static Future<String?> modifyPhone(String phone,String countryCode,String vcode,String password) async {
    final String? result =  await _channel.invokeMethod('modify_phone'
        ,<String,dynamic>{'phone':phone,'country_code':countryCode,'vcode':vcode,'password':password});
    return result;
  }


  //修改邮箱
  static Future<String?> modifyEmial(String email,String vcode,String password) async {
    final String? result =  await _channel.invokeMethod('modify_email'
        ,<String,dynamic>{'email':email,'vcode':vcode,'password':password});
    return result;
  }

  //修改密码
  static Future<String?> modifyPassword(String oldPassword,String newPassword) async {
    final String? result =  await _channel.invokeMethod('modify_password'
        ,<String,dynamic>{'old_password':oldPassword,'new_password':newPassword});
    return result;
  }

  //修改昵称
  static Future<String?> modifyNickname(String nickname) async {
    final String? result =  await _channel.invokeMethod('modify_nickname'
        ,<String,dynamic>{'nickname':nickname});
    return result;
  }

  //修改头像
  static Future<String?> modifyIcon(String filePath) async {
    final String? result =  await _channel.invokeMethod('modify_icon'
        ,<String,dynamic>{'file_path':filePath});
    return result;
  }

  //获取用户信息
  static Future<String?> queryUsersInfo(String data) async {
    final String? result =  await _channel.invokeMethod('query_users_info'
        ,<String,dynamic>{'data':data});
    return result;
  }

  //绑定第三方账号
  static Future<String?> bandThirdParty(String thirdtype,String thirdid,String accesstoken) async {
    final String? result =  await _channel.invokeMethod('band_thirdparty'
        ,<String,dynamic>{'thirdtype':thirdtype,'thirdid':thirdid,'accesstoken':accesstoken});
    return result;
  }
  //解绑第三方账号
  static Future<String?> unbandThirdParty(String thirdtype,String thirdid,String topsign) async {
    final String? result =  await _channel.invokeMethod('unband_thirdparty'
        ,<String,dynamic>{'thirdtype':thirdtype,'thirdid':thirdid,'topsign':topsign});
    return result;
  }
  //发送销毁账号验证码
  static Future<String?> sendDestoryAccountCode(String account,String countryCode) async {
    final String? result =  await _channel.invokeMethod('send_destory_account_code'
        ,<String,dynamic>{'account':account,'country_code':countryCode});
    return result;
  }
  //销毁所有家庭数据
  static Future<String?> deleteAllFamilyData(String familyId,String countryCode) async {
    final String? result =  await _channel.invokeMethod('delete_all_familydata'
        ,<String,dynamic>{'familyid':familyId,'country_code':countryCode});
    return result;
  }
  //删除账号
  static Future<String?> deleteAccount(String account,String countryCode,String vcode) async {
    final String? result =  await _channel.invokeMethod('delete_account'
        ,<String,dynamic>{'account':account,'country_code':countryCode,'vcode':vcode});
    return result;
  }

}
